@@ -187,7 +187,8 @@ class VisualizationSetConverter(object):
 
         # ensure the visualization set is in Rhino model units
         units_sys = units_system()
-        if self.vis_set.units is not None and self.vis_set.units != units_sys:
+        if self.vis_set.units is not None and units_sys is not None \
+                and self.vis_set.units != units_sys:
             self.vis_set.convert_to_units(units_sys)
 
         # set up the bounding box and min/max point
@@ -438,7 +439,7 @@ class VisualizationSetConverter(object):
             # translate analysis point
             pt = from_point3d(geo_obj) if isinstance(geo_obj, Point3D) \
                 else from_point2d(geo_obj)
-            self.draw_point.append((pt, rd.PointStyle.RoundSimple, 3, col))
+            self.draw_point.append((pt, rd.PointStyle.RoundSimple, 5, col))
 
         elif isinstance(geo_obj, (LineSegment3D, LineSegment2D)):
             # translate analysis line segment
